/**
 * module gérant le composant Vue sur la page index.html
 * Ce composant permet de choisir un nom lieu, d'afficher les lieux trouvés
 * avec l'API de Geocodage OpenWeatherMap correspondant à ce nom, et ensuite 
 * consulter la météo du lieux sélectionné parmi les lieux trouvés.
 */

import { getLocation, getCurrentWeather } from "./openWeatherUtils.js";
const vueApp = Vue.createApp({
   data() {
      return {
         locationName: "",
         foundLocations: [],
         selectedLocation: null,
         selectedLocationWeather: null,
      };
   },
   methods: {
      async findLocation() {
            let rep = await getLocation(this.locationName);
            this.foundLocations = rep;
            if (this.foundLocations.length > 0) {
               await this.selectLocation(this.foundLocations[0]);
            }
            else {
               this.selectedLocation = null;
            }
      },

      async selectLocation(location) {
            if (this.selectedLocation) {
               this.selectedLocation.selected = false;
            }
            location.selected = true;
            this.selectedLocation = location;
            this.selectedLocationWeather = await getCurrentWeather(location);

      },
   },

});
let vm = vueApp.mount("#vueApp"); // vm contient l'instance de l'application Vue montée
//  ce qui permet d'accéder à ses propriétés et méthodes.



